@@ -117,6 +117,8 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       dsize=nsize
       info=0
+      dvar = 0.0D+00
+      dtotpesi = 0.0D+00
 C
 C     Check the presence of the intercept
 C
@@ -244,23 +246,3 @@ C      write(*,*) cp(nmaxsol*(imodel-1)+isol,npre+1)
  900  continue
       return
       end
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
